@@ -1,6 +1,6 @@
 //! # Rust Python Integration Made Easy
 //! 
-//! ## What is this for?
+//! ## What is this for
 //! 
 //! PIME is a Rust crate, which allows [tokio](https://tokio.rs)-based Rust
 //! programs to easily execute Python code snippets.
@@ -218,7 +218,7 @@ impl Error {
             traceback: None,
         })
     }
-    pub fn new_py(error: (String, String, String)) -> Box<Self> {
+    fn new_py(error: (String, String, String)) -> Box<Self> {
         Box::new(Self {
             kind: ErrorKind::PythonError,
             exception: Some(error.0),
@@ -227,7 +227,7 @@ impl Error {
         })
     }
 
-    pub fn new_internal(message: String) -> Box<Self> {
+    fn new_internal(message: String) -> Box<Self> {
         Box::new(Self {
             kind: ErrorKind::PySyncEngineStateError,
             message: format!("CRITICAL: PySyncEngine internal error: {}", message),
@@ -236,7 +236,7 @@ impl Error {
         })
     }
 
-    pub fn new_offline() -> Self {
+    fn new_offline() -> Self {
         Self {
             kind: ErrorKind::PySyncEngineStateError,
             message: "PySyncEngine is offline".to_owned(),
@@ -245,7 +245,7 @@ impl Error {
         }
     }
 
-    pub fn new_online() -> Self {
+    fn new_online() -> Self {
         Self {
             kind: ErrorKind::PySyncEngineStateError,
             message: "PySyncEngine is online".to_owned(),
@@ -253,14 +253,6 @@ impl Error {
             traceback: None,
         }
     }
-    pub fn new_not_ready() -> Self {
-        Self {
-            kind: ErrorKind::PySyncEngineStateError,
-            message: "PySyncEngine is not initialized".to_owned(),
-            exception: None,
-            traceback: None,
-        }
-    }
 }
 
 #[derive(Debug)]
@@ -482,7 +474,7 @@ impl<'p> PySyncEngine<'p> {
         Ok(())
     }
 
-    pub fn launch(&self, py: &'p pyo3::Python, exec_func: &pyo3::PyAny) -> Result<(), Box<Error>> {
+    pub fn launch(&self, py: &'p pyo3::Python, broker: &pyo3::PyAny) -> Result<(), Box<Error>> {
         need_offline!();
 
         let mut rx = DC.rx.try_lock()?;
@@ -527,14 +519,14 @@ impl<'p> PySyncEngine<'p> {
                         continue;
                     }
                     if task.need_result {
-                        match call.call1((task_id, exec_func, command.unwrap(), params.unwrap())) {
+                        match call.call1((task_id, broker, command.unwrap(), params.unwrap())) {
                             Ok(_) => {}
                             Err(e) => {
                                 report_error(task_id, Error::new(ErrorKind::ExecError, tostr!(e)));
                             }
                         }
                     } else {
-                        let _ = spawn.call1((exec_func, command.unwrap(), params.unwrap()));
+                        let _ = spawn.call1((broker, command.unwrap(), params.unwrap()));
                     }
                 }
             }
